mDNS is a protocol defined by RFC 6762 that allows querying nodes that correspond to a certain domain name.
In the context of tetsy-libp2p, the mDNS protocol is used to discover other nodes on the local network that support tetsy-libp2p.
Usage
This crate provides the Mdns struct which implements the NetworkBehaviour trait. This
struct will automatically discover other tetsy-libp2p nodes on the local network.
Structs
- Mdns
- A
NetworkBehaviourfor mDNS. Automatically discovers peers on the local network and adds them to the topology. - Mdns
Config
Enums
- Mdns
Event - Event that can be produced by the
Mdnsbehaviour.